@@ -82,6 +82,8 @@ int main (int argc, char *argv[])
     GTKWindow *window;
     GTKVBox *box;
     GTKScrolledWindow *scroll;
+    GTKHandleBox *hbox;
+    GTKToolbar *toolbar;
     GTKMenuBar *menubar;
     GTKMenuItem *item;
     GTKMenu *menu;
@@ -98,8 +100,11 @@ int main (int argc, char *argv[])
     scroll = [GTKScrolledWindow scrolledWindowWithHadjustment:nil
 				vadjustment:nil];
     menubar = [GTKMenuBar menuBar];
-    text = [GTKText textWithHadj:nil vadj:nil];
+    toolbar = [GTKToolbar toolbarWithOrientation:GTK_ORIENTATION_HORIZONTAL
+			  style:GTK_TOOLBAR_TEXT];
     menu = [GTKMenu menu];
+    hbox = [GTKHandleBox handleBox];
+    text = [GTKText textWithHadj:nil vadj:nil];
 
     item = [GTKMenuItem menuItemWithLabel:@"File"];
     [item setSubmenu:menu];
@@ -119,9 +124,19 @@ int main (int argc, char *argv[])
 	  sel:@selector(emit:signal:) data:@"delete_event"];
     [menu append:item];
 
+    [[toolbar appendItem:@"Open..." tooltipText:@"Open File"
+	      tooltipPrivateText:nil icon:nil callback:NULL userData:NULL]
+	connectSignal:@"clicked" withTarget:foo sel:@selector(openFile:)];
+    [[toolbar appendItem:@"Close" tooltipText:@"Close File"
+	      tooltipPrivateText:nil icon:nil callback:NULL userData:NULL]
+	connectSignal:@"clicked" withTarget:window sel:@selector(emit:signal:)
+	data:@"delete_event"];
+
+    [hbox add:toolbar];
     [scroll add:text];
     [text setEditable:YES];
     [box packStart:menubar expand:NO fill:YES padding:0];
+    [box packStart:hbox expand:NO fill:YES padding:0];
     [box packStartDefaults:scroll];
 
     [window setDelegate:foo];
