@@ -1,6 +1,6 @@
 /*
  * GToolKit - Objective-C interface to the GIMP Toolkit
- * Copyright (c) 1998  Elmar Ludwig - Universitaet Osnabrueck
+ * Copyright (c) 2000  Elmar Ludwig - Universitaet Osnabrueck
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -34,6 +34,7 @@
     SEL selector;	// target selector to perform
     IMP method;		// target function pointer
     void *data;		// optional user data
+    BOOL retained;	// user data should be retained
 }
 
 /* creating actions */
@@ -43,11 +44,13 @@
 - initWithTarget:target selector:(SEL) selector data:(const void *) data;
 - (void) setTarget:target selector:(SEL) selector;
 - (void) setData:(const void *) data;
+- (void) retainData;
 
 /* inspecting action values */
 - target;
 - (SEL) selector;
 - (void *) data;
+- (BOOL) dataRetained;
 
 /* invoking an action */
 - (void) performWithSender:sender args:(GtkArg *) args count:(unsigned) count;
